============
Installation
============

At the command line::

    $ easy_install hamster-dbus

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv hamster-dbus
    $ pip install hamster-dbus
